#
#   Pyrex - Errors
#

import sys

class PyrexError(Exception):
  pass


class CompileError(PyrexError):
  
  def __init__(self, position, message):
    self.position = position
    self.message = message
    file, line, col = position
    Exception.__init__(self, 
      '"%s":%d:%d: %s' % (file, line, col, message))


class InternalError(Exception):
  # If this is ever raised, there is a bug in the compiler.
  
  def __init__(self, message):
    Exception.__init__(self, "Internal compiler error: %s"
      % message)
      

listing_file = None
num_errors = 0

def open_listing_file(path):
  global listing_file, num_errors
  listing_file = open(path, "w")
  num_errors = 0

def close_listing_file():
  global listing_file
  if listing_file:
    listing_file.close()
    listing_file = 0

def error(position, message):
  global num_errors
  err = CompileError(position, message)
  mess = "%s\n" % err
  sys.stderr.write(mess)
  if listing_file:
    listing_file.write(mess)
  num_errors = num_errors + 1
  return err
